# -*- coding: utf-8 -*-
# Copyright © 2007 Lateef Alabi-Oki
#
# This file is part of Striim.
#
# Striim is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Striim is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Striim; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

def main(argv):
	"""
	Main entry point to program.

	@param argv: Command line arguments.
	@type argv: A List object.
	"""
	__launch_player(argv)
	__mainloop()
	return

def __launch_player(argv):
	"""
	Initialize striim, or show striim if already initialized.

	@param argv: Command line arguments.
	@type argv: A List object.
	"""
	dbus_object = __get_dbus_object()
	if dbus_object:
		# Show the player if it's already running.
		from operator import not_
		if not_(argv): argv = ""
		dbus_object.show_player(argv)
		raise SystemExit
	else:
		# Initialize the player.
		from gobject import threads_init, idle_add
		threads_init()
		idle_add(__init_instance_manager, argv)
	return

def __init_instance_manager(argv):
	"""
	Initialize striim's instance manager.

	@param argv: Possible command line arguments.
	@type argv: A List object.
	"""
	from InstanceManager import InstanceManager
	InstanceManager(argv)
	return False

def __get_dbus_object():
	"""
	Get a D-Bus object representing a running striim process.

	@param return: An object representing a running striim process.
	@param type: #FIXME: ????, or None.
	"""
	from Global import dbus_iface, session_bus, dbus_service_name
	from Global import dbus_object_path
	services = dbus_iface.ListNames()
	from operator import contains, not_
	if not_(contains(services, dbus_service_name)): return None
	proxy_object = session_bus.get_object(dbus_service_name, dbus_object_path)
	return proxy_object

def __mainloop():
	"""
	Initialize the GObject mainloop.
	"""
	__fork_striim()
#	from utils import init_gnome
#	init_gnome()
	from gobject import MainLoop
	mainloop = MainLoop()
	mainloop.run()
	return

def __fork_striim():
	"""
	Detach striim from the shell terminal and run it in its own
	process.
	"""
	from operator import ne, not_
	if not_(__can_fork()): return
	from os import fork
	pid = fork()
	if ne(pid, 0):
		from sys import exit
		exit(0)
	return

def __can_fork():
	"""
	Whether or not to detach striim from the shell terminal.

	@param return: True to detach striim from the shell terminal.
	@param type: A Boolean object.
	"""
	from gconf import client_get_default
	client = client_get_default()
	fork_striim = True
	from operator import truth
	if truth(client.get("/apps/striim/fork_striim")):
		fork_striim = client.get_bool("/apps/striim/fork_striim")
	return fork_striim
