# -*- coding: utf-8 -*-
# Copyright © 2006 Lateef Alabi-Oki
#
# This file is part of striim.
#
# striim is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# striim is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with striim; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

"""
This module documents a class that creates a trigger that shows striim's
user guide.

@author: Lateef Alabi-Oki
@organization: The striim Project
@copyright: Copyright © 2006 Lateef Alabi-Oki
@license: GNU GPLv2 or Later
@contact: mystilleef@gmail.com
"""

from gobject import GObject, SIGNAL_RUN_LAST, TYPE_NONE

class UserGuideTrigger(GObject):
	"""
	This class creates an object, a trigger, that shows striim's user
	guide.
	"""

	__gsignals__ = {
		"destroy": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
	}

	def __init__(self, player):
		"""
		Initialize the trigger.

		@param self: Reference to the UserGuideTrigger instance.
		@type self: A UserGuideTrigger object.

		@param player: Reference to the Player instance.
		@type player: A Player object.
		"""
		GObject.__init__(self)
		self.__init_attributes(player)
		self.__create_triggers()
		self.__signal_id_1 = self.__trigger.connect("activate", self.__show_user_guide_cb)
		self.__signal_id_3 = self.__trigger_1.connect("activate", self.__show_user_guide_cb)
		self.__signal_id_2 = self.connect("destroy", self.__destroy_cb)

	def __init_attributes(self, player):
		"""
		Initialize the trigger's attributes.

		@param self: Reference to the UserGuideTrigger instance.
		@type self: A UserGuideTrigger object.

		@param editor: Reference to the text editor.
		@type editor: An Editor object.
		"""
		self.__player = player
		self.__trigger = None
		self.__signal_id_2 = self.__signal_id_1 = None
		self.__signal_id_3 = None
		return

	def __create_triggers(self):
		"""
		Create the trigger.

		@param self: Reference to the UserGuideTrigger instance.
		@type self: A UserGuideTrigger object.
		"""
		# Trigger to user guide.
		from Striim.Trigger import Trigger
		self.__trigger = Trigger("show_user_guide", "F1")
		self.__trigger_1 = Trigger("show_manual", "h")
		triggers = [self.__trigger, self.__trigger_1]
		self.__player.add_triggers(triggers)
		return

	def __show_user_guide_cb(self, trigger):
		"""
		Handles callback when the "activate" signal is emitted.

		@param self: Reference to the UserGuideTrigger instance.
		@type self: A UserGuideTrigger object.

		@param trigger: An object to show the document browser.
		@type trigger: A Trigger object.
		"""
		from gnome import help_display
		if help_display("/striim.xml"):
			from i18n import msg0001
			self.__player.feedback.update_status_message(msg0001, "help", 10)
		else:
			from i18n import msg0002
			self.__player.feedback.update_status_message(msg0002, "fail", 10)
		return

	def __destroy_cb(self, trigger):
		"""
		Handles callback when the "activate" signal is emitted.

		@param self: Reference to the UserGuideTrigger instance.
		@type self: An UserGuideTrigger object.

		@param trigger: Reference to the UserGuideTrigger instance.
		@type trigger: A UserGuideTrigger object.
		"""
		triggers = [self.__trigger, self.__trigger_1]
		self.__player.remove_triggers(triggers)
		from Striim.utils import disconnect_signal, delete_attributes
		disconnect_signal(self.__signal_id_1, self.__trigger)
		disconnect_signal(self.__signal_id_3, self.__trigger_1)
		disconnect_signal(self.__signal_id_2, self)
		delete_attributes(self)
		del self
		self = None
		return

	def destroy(self):
		self.emit("destroy")
		return
