# -*- coding: utf-8 -*-
# Copyright © 2005 Lateef Alabi-Oki
#
# This file is part of striim.
#
# Scribe is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# striim is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with striim; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

"""
This module exposes functions that store the stations and playlist
information in a database.

@author: Lateef Alabi-Oki
@organization: The striim Project
@copyright: Copyright © 2005 Lateef Alabi-Oki
@license: GNU GPLv2 or Later
@contact: mystilleef@gmail.com
"""

def open_volume_database(flag="c"):
	"""
	Open the volume database.

	@return: A database that stores the current volume level.
	@rtype: A database Shelve object.
	"""
	from Striim.Global import metadata_folder
	from os import path
	if not path.exists(metadata_folder):
		from os import makedirs
		makedirs(metadata_folder)
	database_file = path.join(metadata_folder, "volume.gdb")
	from shelve import open
	from anydbm import error
	try:
		database = open(database_file, flag=flag, writeback=False)
	except error:
		database = open(database_file, flag="n", writeback=False)
	return database

def get_volume_from_database():
	"""
	Get volume for striim

	@return: Volume level value.
	@rtype: A dictionary object.
	"""
	database = open_volume_database("r")
	try:
		volume = database["volume"]
		database.close()
	except:
		volume = 0.2
		database.close()
	return volume

def update_volume_database(data):
	"""
	Store volume in database.

	A dictionary of the format:

		{"volume": float}

	@param data: A dictionary with volume information.
	@type data: A Dictionary object.
	"""
	database = open_volume_database("w")
	database["volume"] = data
	database.close()
	return
